@@ -1,10 +1,10 @@
-__version__ = "0.1.22"
+__version__ = "0.1.23"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.1.23)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '3e9b0ba51bb38fb77729be43bd1e498a774078ab'
-__git_head_subject__ = 'Finished release v0.1.22.'
+__git_head_hash__ = '478c9b141af62b3c5d248f124fdc2cf30201578d'
+__git_head_subject__ = 'Finished release v0.1.23.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
